//
//  AppDelegate.swift
//  CoreDataMacoun
//
//  Created by Benedikt Terhechte on 10/10/15.
//  Copyright © 2015 Benedikt Terhechte. All rights reserved.
//

import Cocoa
import CoreData

func setUpInMemoryManagedObjectContext(model: String, inBundle: NSBundle) -> NSManagedObjectContext? {
    guard let modelURL = inBundle.URLForResource(model, withExtension: "momd")
        else { return nil }
    
    let managedObjectModel = NSManagedObjectModel(contentsOfURL: modelURL)!
    
    let persistentStoreCoordinator = NSPersistentStoreCoordinator(managedObjectModel: managedObjectModel)
    do {
        try persistentStoreCoordinator.addPersistentStoreWithType(NSInMemoryStoreType, configuration: nil, URL: nil, options: nil)
    } catch _ {
        return nil
    }
    
    let managedObjectContext = NSManagedObjectContext(concurrencyType: .MainQueueConcurrencyType)
    managedObjectContext.persistentStoreCoordinator = persistentStoreCoordinator
    
    return managedObjectContext
}

@NSApplicationMain
class AppDelegate: NSObject, NSApplicationDelegate {

    @IBOutlet weak var window: NSWindow!


    func applicationDidFinishLaunching(aNotification: NSNotification) {
        let aBookmark1 = Bookmark(title: "Bookmark 1", pagerank: 33, url: "www.aol.com", created: NSDate(),
            keywords: [Keyword(name: "aol"), Keyword(name: "1990")], group: .Entertainment)
        let aBookmark2 = Bookmark(title: "Bookmark 2", pagerank: 13, url: "www.cnn.com", created: NSDate(),
            keywords: [Keyword(name: "cnn"), Keyword(name: "news")], group: .News)
        let aBookmark3 = Bookmark(title: "Bookmark 3", pagerank: 43, url: "www.macoun.de", created: NSDate(),
            keywords: [Keyword(name: "osx"), Keyword(name: "ios"), Keyword(name: "")], group: .Business)
        do {
            try aBookmark1.toCoreData(self.managedObjectContext)
            try aBookmark2.toCoreData(self.managedObjectContext)
            try aBookmark3.toCoreData(self.managedObjectContext)
        } catch let e {
            print("Fehler:", e)
        }
    }
    
    func applicationWillTerminate(aNotification: NSNotification) {
        // Insert code here to tear down your application
    }

    // MARK: - Core Data stack

    lazy var managedObjectContext: NSManagedObjectContext = {
        guard let context = setUpInMemoryManagedObjectContext("CoreDataMacoun", inBundle: NSBundle.mainBundle())
            else { fatalError("Could  not create context") }
        return context
    }()
    
    // MARK: - Core Data Saving and Undo support

    func applicationShouldTerminate(sender: NSApplication) -> NSApplicationTerminateReply {
        return .TerminateNow
    }

}

